<?php

namespace Bixo\HrRequest\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\HrRequest\Models\HrRequests;

class HrRequestsPolicy
{

    /**
     * Determine if the given user can view the hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function view(UserPolicy $user, HrRequests $hr_requests)
    {
        if ($user->canDo('hr_request.hr_requests.view') && $user->isAdmin()) {
            return true;
        }

        return $hr_requests->user_id == user_id() && $hr_requests->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hr_request.hr_requests.create');
    }

    /**
     * Determine if the given user can update the given hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function update(UserPolicy $user, HrRequests $hr_requests)
    {
        if ($user->canDo('hr_request.hr_requests.edit') && $user->isAdmin()) {
            return true;
        }

        return $hr_requests->user_id == user_id() && $hr_requests->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, HrRequests $hr_requests)
    {
        return $hr_requests->user_id == user_id() && $hr_requests->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function verify(UserPolicy $user, HrRequests $hr_requests)
    {
        if ($user->canDo('hr_request.hr_requests.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hr_requests.
     *
     * @param UserPolicy $user
     * @param HrRequests $hr_requests
     *
     * @return bool
     */
    public function approve(UserPolicy $user, HrRequests $hr_requests)
    {
        if ($user->canDo('hr_request.hr_requests.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
