<?php

namespace Bixo\HrRequest\Providers;

use Illuminate\Support\ServiceProvider;

class HrRequestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'hr_request');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'hr_request');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerHrRequest();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerHrRequest()
    {
        $this->app->bind('hr_request', function($app) {
            return new HrRequest($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('HrRequest', 'Lavalite\HrRequest\Facades\HrRequest');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.hr_request', function ($app) {
            return $this->app->make('Bixo\HrRequest\HrRequest');
        });

                // Bind HrRequests to repository
        $this->app->bind(
            'Bixo\HrRequest\Interfaces\HrRequestsRepositoryInterface',
            \Bixo\HrRequest\Repositories\Eloquent\HrRequestsRepository::class
        );

        $this->app->register(\Bixo\HrRequest\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\HrRequest\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and hr_request's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.hr_request'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeHrRequest::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.hr_request'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/hr_request.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/hr_request')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/hr_request')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
